@@ -1,10 +1,40 @@
 # 2022.3.3  uvicorn annotate:app --host 0.0.0.0 --port 18000 --reload
 import json,requests,hashlib,os
 from uvirun import * 
-from en import nlp 
+from en import nlp , snts
 from en.terms import *
 os.dskurl = os.getenv('dskurl',"gpu120.wrask.com:9102")
 
+def stag(snt):
+	sdoc = nlp(snt)
+	tags = []
+	tags.append ("简单句" if len([t for t in sdoc if t.pos_ == 'VERB' and t.dep_ != 'ROOT']) <= 0 else "复杂句" )
+	if len([t for t in sdoc if t.dep_ == 'conj' and t.head.dep_ == 'ROOT']) > 0:
+		tags.append('并列句')
+	return tags 
+
+@app.post('/annotate/tagsnts')
+def annotate_tagsnts(snts:list=["I think that I am going to go to the cinema.","The quick fox jumped over the lazy dog."]):  
+	''' sentence level tags ''' 
+	return [ (snt, stag(snt)) for snt in snts ]
+
+@app.get('/annotate/sntbr')
+def annotate_sntbr(text="I think that I am going to go to the cinema. The quick fox jumped over the lazy dog.", trim:bool=True, addtag:bool=True):  
+	''' snt break ''' 
+	docsnts = snts(text, trim) 
+	return docsnts if not addtag else annotate_tagsnts(docsnts)
+
+@app.get('/annotate/spantags')
+def annotate_spantags(text="I think that I am going to go to the cinema. The quick fox jumped over the lazy dog.", classid:int=0):  
+	''' {"code":0,"data":{"entities":[[16,25,"大小写",1],[16,25,"标点符号",2]]}} ''' 
+	doc = nlp(text) 
+	spans = [ [doc[np.start].idx, doc[np.start].idx + len(np.text), "NP", classid] for np in doc.noun_chunks if np.end - np.start > 1]
+	for name, ibeg,iend in matchers['ap'](doc) :
+		spans.append( [doc[ibeg].idx, doc[ibeg].idx + len(doc[ibeg:iend].text), "AP", classid] )
+	for name, ibeg,iend in matchers['vp'](doc) :
+		spans.append( [doc[ibeg].idx, doc[ibeg].idx + len(doc[ibeg:iend].text), "VP", classid] )
+	return {"code":0, "data":{"entities":spans} }
+
 @app.get('/annotate/phrase')
 def annotate_phrase(text="I think that I am going to go to the cinema. The quick fox jumped over the lazy dog.", classes:str="NP,VP,AP"):  
 	''' {"classes":["NP","NP2"],"annotations":[["Terrible customer service.",{"entities":[[0,17,"NP2"],[18,25,"NP"]]}], ''' 
